/*********************************************************************************************************
* Software License Agreement (BSD License)                                                               *
* Author: Sebastien Decugis <sdecugis@nict.go.jp>							 *
*													 *
* Copyright (c) 2008, WIDE Project and NICT								 *
* All rights reserved.											 *
* 													 *
* Redistribution and use of this software in source and binary forms, with or without modification, are  *
* permitted provided that the following conditions are met:						 *
* 													 *
* * Redistributions of source code must retain the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer.										 *
*    													 *
* * Redistributions in binary form must reproduce the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer in the documentation and/or other						 *
*   materials provided with the distribution.								 *
* 													 *
* * Neither the name of the WIDE Project or NICT nor the 						 *
*   names of its contributors may be used to endorse or 						 *
*   promote products derived from this software without 						 *
*   specific prior written permission of WIDE Project and 						 *
*   NICT.												 *
* 													 *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED *
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A *
* PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR *
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 	 *
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 	 *
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR *
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF   *
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.								 *
*********************************************************************************************************/

/* Header file for the app_test extension. 
 *
 *  This extension provides a way to send configurable messages on the network
 *
 *  See the app_test.conf.sample file for the format of the configuration file.
 */
 
#define IN_EXTENSION
#include <waaad/waaad.h>

#include <pthread.h>
#include <stdlib.h>
#include <string.h>
#include <signal.h>

/* The module configuration */
typedef struct {
	/* debug level */
	int 	signal;		/* default: SIGUSR1 */
	
} atst_conf_t;
extern atst_conf_t * atst_conf;


/* Parse the configuration file */
int conf_parse(char * conffile);

/* Start or stop the signal handler */
int sig_init(void (*cb)(void));
void sig_fini(void);

/* Initialize dictionary definitions */
int dict_init(void);

/* Handle incoming messages */
int disp_init(void);
void disp_fini(void);

/* Create outgoing message */
void send_test_message(void);


/**********************************************************************************
 * Define the TRACE_DEBUG macro to be used similarly as in the daemon (see log.h)
 **********************************************************************************/
#define NONE 0
#define INFO 1
#define FULL 2
#ifndef TRACE_LEVEL 
#define TRACE_LEVEL INFO
#endif /* TRACE_LEVEL */
static int debug_level = TRACE_LEVEL;
#define TRACE_DEBUG(level,format,args... ) \
	{ if ( level <= debug_level ) \
		log_debug("%-12s:%-4d( %-15s): " format "\n", __FILE__, __LINE__, __FUNCTION__, ## args); }
#define TRACE_ENTRY(_format,_args... ) \
	TRACE_DEBUG(FULL, "Entering ext function (parms: " _format ")", ##_args )
/**************************************************************************************/
